@@ -31,7 +31,11 @@
 //!
 //! \brief      GSH settings for Xe_hpg_base
 //!
-#define RENDERHAL_SAMPLERS_AVS_HPG_BASE          0
+#define RENDERHAL_SAMPLERS_AVS_HPG_BASE        0
+#define ENLARGE_KERNEL_COUNT_HPG_BASE          RENDERHAL_KERNEL_COUNT * 3
+#define ENLARGE_KERNEL_HEAP_HPG_BASE           RENDERHAL_KERNEL_HEAP * 3
+#define ENLARGE_CURBE_SIZE_HPG_BASE            RENDERHAL_CURBE_SIZE * 16
+#define ENLARGED_SSH_BINDING_TABLES_HPG_BASE   16
 
 extern const RENDERHAL_STATE_HEAP_SETTINGS g_cRenderHal_State_Heap_Settings_hpg_base =
 {
@@ -58,7 +62,19 @@ extern const RENDERHAL_STATE_HEAP_SETTINGS g_cRenderHal_State_Heap_Settings_hpg_
     RENDERHAL_SSH_BINDING_TABLES,              //!< iBindingTables
     RENDERHAL_SSH_SURFACE_STATES,              //!< iSurfaceStates
     RENDERHAL_SSH_SURFACES_PER_BT,             //!< iSurfacesPerBT
-    RENDERHAL_SSH_BINDING_TABLE_ALIGN          //!< iBTAlignment
+    RENDERHAL_SSH_BINDING_TABLE_ALIGN,         //!< iBTAlignment
+    MOS_CODEC_RESOURCE_USAGE_BEGIN_CODEC       //!< heapUsageType
+};
+
+extern const RENDERHAL_ENLARGE_PARAMS g_cRenderHal_Enlarge_State_Heap_Settings_Adv_hpg_base =
+{
+    ENLARGED_SSH_BINDING_TABLES_HPG_BASE,   //!< iBindingTables
+    RENDERHAL_SSH_SURFACE_STATES_MAX,       //!< iSurfaceStates
+    RENDERHAL_SSH_SURFACES_PER_BT,          //!< iSurfacesPerBT
+    ENLARGE_KERNEL_COUNT_HPG_BASE,          //!< iKernelCount
+    ENLARGE_KERNEL_HEAP_HPG_BASE,           //!< iKernelHeapSize
+    ENLARGE_CURBE_SIZE_HPG_BASE,            //!< iCurbeSize
+    RENDERHAL_MEDIA_IDS                     //!< iMediaIDs
 };
 
 const uint32_t g_cLookup_RotationMode_hpg_base[8] = 
@@ -216,6 +232,15 @@ MOS_STATUS XRenderHal_Interface_Xe_Hpg_Base::SetupSurfaceState(
                 SurfStateParams.dwCompressionFormat = 0;
             }
 
+            if (pParams->isOutput &&
+                pSurface->MmcState == MOS_MEMCOMP_RC &&
+                pSurface->OsResource.bUncompressedWriteNeeded)
+            {
+                MHW_RENDERHAL_NORMALMESSAGE("force uncompressed write if requested from resources");
+                SurfStateParams.MmcState = MOS_MEMCOMP_MC;
+                SurfStateParams.dwCompressionFormat = 0;
+            }
+
             if (!pParams->isOutput &&
                 pSurface->MmcState != MOS_MEMCOMP_DISABLED &&
                 pSurfaceEntry->bVertStride)
@@ -349,7 +374,9 @@ void XRenderHal_Interface_Xe_Hpg_Base::InitStateHeapSettings(
 {
     MHW_RENDERHAL_CHK_NULL_NO_STATUS_RETURN(pRenderHal);
     // Set State Heap settings for hpg_base
-    pRenderHal->StateHeapSettings = g_cRenderHal_State_Heap_Settings_hpg_base;
+    pRenderHal->StateHeapSettings              = g_cRenderHal_State_Heap_Settings_hpg_base;
+    pRenderHal->defaultStateHeapSettings       = g_cRenderHal_State_Heap_Settings_hpg_base;
+    pRenderHal->enlargeStateHeapSettingsForAdv = g_cRenderHal_Enlarge_State_Heap_Settings_Adv_hpg_base;
 }
 
 //!
