@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2022, Intel Corporation
+* Copyright (c) 2018-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -45,24 +45,6 @@
 
 namespace decode {
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    typedef struct _DECODE_EVENTDATA_YUV_SURFACE_INFO
-    {
-        uint32_t PicFlags;
-        uint32_t FrameType;
-        uint32_t dwOffset;
-        int32_t  YPlaneOffset_iYOffset;
-        uint32_t dwPitch;
-        uint32_t dwWidth;
-        uint32_t dwHeight;
-        uint32_t Format;
-        int32_t  UPlaneOffset_iLockSurfaceOffset;
-        int32_t  VPlaneOffset_iLockSurfaceOffset;
-        int32_t  UPlaneOffset_iSurfaceOffset;
-        int32_t  VPlaneOffset_iSurfaceOffset;
-    } DECODE_EVENTDATA_YUV_SURFACE_INFO;
-#endif
-
 enum DecodePipeMode
 {
     decodePipeModeBegin = 0,
@@ -249,9 +231,9 @@ public:
     //!
     //! \return   True if guc submission mode, otherwise return false
     //!
-    virtual bool IsGucSubmission()
+    virtual bool IsParallelSubmission()
     {
-        return m_osInterface->bGucSubmission;
+        return m_osInterface->bParallelSubmission;
     }
 
 #ifdef _DECODE_PROCESSING_SUPPORTED
@@ -337,6 +319,28 @@ public:
     //!
     virtual MOS_STATUS SetDecodeFormat(bool isShortFormat ){ return MOS_STATUS_UNIMPLEMENTED; };
 
+#if (_DEBUG || _RELEASE_INTERNAL)
+    //!
+    //! \brief  CRC output enable
+    //! \return bool
+    //!         true if enabled, else false
+    //!
+    bool GetCRCOutputEnable()
+    {
+        return m_crcoutputEnable;
+    }
+
+    //!
+    //! \brief  Get Vdbox command counter override value
+    //! \return uint32_t
+    //!         command counter override value
+    //!
+    uint32_t GetVdboxCommandCounterOverride()
+    {
+        return m_vdboxCommandCounterOverride;
+    }
+#endif
+
 protected:
     //!
     //! \brief  Initialize the decode pipeline
@@ -421,6 +425,28 @@ protected:
     MOS_STATUS DumpDownSamplingParams(DecodeDownSamplingFeature &downSamplingParams);
 #endif
 
+    //!
+    //! \brief  Dump Bitstream
+    //! \param  [in] pBitstream
+    //!         Bitstream Resource
+    //! \param  [in] size
+    //!         Bitstream Size
+    //! \param  [in] offset
+    //!         Bitstream Offset 
+    //! \param  [in] attrName
+    //!         Bitstream Name
+    //! \return MOS_STATUS
+    //!         MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS DumpBitstream(PMOS_RESOURCE pBitstream, uint32_t size, uint32_t offset, const char* attrName = nullptr);
+
+    //!
+    //! \brief  Add delay for dump render targets
+    //! \return MOS_STATUS
+    //!         MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS DelayForDumpOutput();
+
     //!
     //! \brief  Dump render targets
     //! \param  [in] reportData
@@ -431,11 +457,6 @@ protected:
     virtual MOS_STATUS DumpOutput(const DecodeStatusReportData& reportData);
 #endif
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    MOS_STATUS TraceDataDumpOutput(const DecodeStatusReportData &reportData);
-    MOS_STATUS TraceDataDump2ndLevelBB(PMHW_BATCH_BUFFER batchBuffer);
-#endif
-
 #if (_DEBUG || _RELEASE_INTERNAL)
     //!
     //! \brief  User feature key report for Vdbox IDs
@@ -474,7 +495,7 @@ protected:
     //! \return MOS_STATUS
     //!         MOS_STATUS_SUCCESS if success, else fail reason
     //!
-    MOS_STATUS StatusCheck();
+    virtual MOS_STATUS StatusCheck();
 #endif
 
 protected:
@@ -497,6 +518,7 @@ protected:
     MOS_STATUS CreateSubPacketManager(CodechalSetting* codecSettings);
 
     friend class DecodeSubPipelineManager;
+    friend class DecodeStreamOut;
 
     CodechalHwInterfaceNext *m_hwInterface        = nullptr;  //!< Codechal HwInterface
     CodechalOcaDumper      *m_pCodechalOcaDumper = nullptr;
@@ -525,6 +547,8 @@ protected:
 #if (_DEBUG || _RELEASE_INTERNAL)
     uint32_t                m_statusCheckCount = 0;     //!< count for status check
     uint32_t                m_delayMiliseconds = 0;     //!< miliseconds delay after each frame
+    uint32_t                m_crcoutputEnable  = 0;     //!< crc output enable
+    uint32_t                m_vdboxCommandCounterOverride = 0;  //!< vdbox command counter override
 #endif
 
     PMOS_SURFACE            m_tempOutputSurf = nullptr;
