@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2023, Intel Corporation
+* Copyright (c) 2018-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -37,6 +37,9 @@ using MosFormatArray = std::vector<MOS_FORMAT>;
 #define VP_HW_ASSERTMESSAGE(_message, ...)                                        \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_HW, _message, ##__VA_ARGS__)
 
+#define VP_HW_WARNINGMESSAGE(_message, ...)                                       \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_HW, _message, ##__VA_ARGS__)
+
 #define VP_HW_NORMALMESSAGE(_message, ...)                                        \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_HW, _message, ##__VA_ARGS__)
 
@@ -72,6 +75,9 @@ using MosFormatArray = std::vector<MOS_FORMAT>;
     OcaOnMosCriticalMessage(MOS_FUNCTION, __LINE__);
 #endif
 
+#define VP_PUBLIC_WARNINGMESSAGE(_message, ...)                                   \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_PUBLIC, _message, ##__VA_ARGS__)
+
 #define VP_PUBLIC_NORMALMESSAGE(_message, ...)                                    \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_PUBLIC, _message, ##__VA_ARGS__)
 
@@ -128,6 +134,9 @@ using MosFormatArray = std::vector<MOS_FORMAT>;
 #define VP_DEBUG_ASSERTMESSAGE(_message, ...)                                     \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
 
+#define VP_DEBUG_WARNINGMESSAGE(_message, ...)                                    \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
+
 #define VP_DEBUG_NORMALMESSAGE(_message, ...)                                     \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DEBUG, _message, ##__VA_ARGS__)
 
@@ -169,6 +178,9 @@ using MosFormatArray = std::vector<MOS_FORMAT>;
     OcaOnMosCriticalMessage(MOS_FUNCTION, __LINE__);
 #endif
 
+#define VP_RENDER_WARNINGMESSAGE(_message, ...)                                   \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_RENDER, _message, ##__VA_ARGS__)
+
 #define VP_RENDER_NORMALMESSAGE(_message, ...)                                    \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_RENDER, _message, ##__VA_ARGS__)
 
@@ -208,6 +220,9 @@ using MosFormatArray = std::vector<MOS_FORMAT>;
 #define VP_DDI_ASSERTMESSAGE(_message, ...)                                          \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DDI, _message, ##__VA_ARGS__)
 
+#define VP_DDI_WARNINGMESSAGE(_message, ...)                                         \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DDI, _message, ##__VA_ARGS__)
+
 #define VP_DDI_NORMALMESSAGE(_message, ...)                                          \
     MOS_NORMALMESSAGE(MOS_COMPONENT_VP, MOS_VP_SUBCOMP_DDI, _message, ##__VA_ARGS__)
 
@@ -317,6 +332,7 @@ protected:
 #define __VPHAL_HDR_H2S_RGB_TM                                          "VPHAL H2S TM RGB Based"
 #define __VPHAL_HDR_3DLUT_CPU_PATH                                      "HDR 3DLut Table Use CPU Caculate"
 #define __VPHAL_FORCE_VP_3DLUT_KERNEL_ONLY                              "Force VP 3DLut Kernel Only"
+#define __VPHAL_3DLUT_FILE_PATH                                         "3DLUT File Path"
 
 // Compression
 #define __VPHAL_MMC_ENABLE                                              "VP MMC In Use"
@@ -482,6 +498,26 @@ public:
         VPHAL_CSPACE          srcCspace,
         VPHAL_CSPACE          dstCspace);
 
+    //!
+    //! \brief    Performs Color Space Convert for Sample Pixel Float
+    //! \details  Performs Color Space Convert from Src Color Spase to Dst Color Spase
+    //! \param    [out] pOutput
+    //!           Pointer to float
+    //! \param    [in] pInput
+    //!           Pointer to VPHAL_COLOR_SAMPLE_8
+    //! \param    [in] srcCspace
+    //!           Source Color Space
+    //! \param    [in] dstCspace
+    //!           Dest Color Space
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful
+    //!
+    static MOS_STATUS GetPixelWithCSCForColorFillFloat(
+        float                 input[4],
+        float                 output[4],
+        VPHAL_CSPACE          srcCspace,
+        VPHAL_CSPACE          dstCspace);
+
     //!
     //! \brief    Get Color Space Convert Normalized Matrix
     //! \details  Get Color Space Convert Normalized Matrix
